@@ -56,11 +56,25 @@ class Api():
         self.header = {'Content-Type': 'application/json',
                        'Accept': 'application/json',
                        'Accept-Encoding': 'message/rfc822'}
+        self.session = Session()
+        self.retry = Retry(connect=3, backoff_factor=0.5)
+        self.adapter = HTTPAdapter(max_retries=self.retry)
         # self.session = Session()
         # retry = Retry(connect=3, backoff_factor=0.5)
         # adapter = HTTPAdapter(max_retries=retry)
         # self.session.mount('http://', adapter)
 
+    def close_session(self):
+        self.session.close()
+
+    def open_new_session(self):
+        if self.session != None:
+            self.close_session()
+        session = Session()
+        session.config['keep_alive'] == False
+        session.mount('http://', self.adapter)
+
+
     def __to_format(self, response):
         """A private method to return the API response in the desired format
             @param self - the object pointer
@@ -82,13 +96,9 @@ class Api():
             @param self - the object pointer
             @param url - API URL to access
         """
-        session = Session()
-        retry = Retry(connect=3, backoff_factor=0.5)
-        adapter = HTTPAdapter(max_retries=retry)
-        session.mount('http://', adapter)
         req = Request('POST',url, data=json.dumps(content), headers=self.header)
         prep = req.prepare()
-        resq = session.send(prep,
+        resq = self.session.send(prep,
         stream=None,
         verify=None
         )
